@@ -59,7 +59,7 @@ class TfIdf(VectorizerLayer):
             **kwargs)
 
 
-class Count(VectorizerLayer):
+class CountVectorizer(VectorizerLayer):
     def __init__(
         self,
         input=None,
@@ -72,11 +72,11 @@ class Count(VectorizerLayer):
         verbose=True,
         **kwargs,
     ):
-        from sklearn.feature_extraction.text import CountVectorizer
-        super(Count, self).__init__(input, output, name, verbose)
+        from sklearn.feature_extraction.text import CountVectorizer as CV
+        super(CountVectorizer, self).__init__(input, output, name, verbose)
 
         self.sparse = sparse
-        self.vectorizer = CountVectorizer(
+        self.vectorizer = CV(
             preprocessor=identity,
             tokenizer=identity,
             max_features=max_features,
@@ -85,7 +85,7 @@ class Count(VectorizerLayer):
             **kwargs)
 
 
-class Embedding(Layer):
+class Sequence(Layer):
     parallel = False
     trainable = True
     document_wise = False
@@ -97,15 +97,16 @@ class Embedding(Layer):
         max_features=None,
         min_tf=0,
         maxlen=None,
-        pad=False,
+        pad=True,
         padding="pre",
         unk_token=True,
         mask_token=True,
         word2id=None,
+        model=None,
         name=None,
         verbose=True
     ):
-        super(Embedding, self).__init__(input, output, name, verbose, False)
+        super(Sequence, self).__init__(input, output, name, verbose, False)
         if max_features is None:
             max_features = float("inf")
         self.max_features = max_features
@@ -120,7 +121,18 @@ class Embedding(Layer):
             raise ValueError("padding argument should be 'pre' or 'post'")
         self.unk_token = unk_token
         self.mask_token = mask_token
-        if word2id is not None:
+
+        if model is not None:  # gensim model provided
+            if hasattr(model, "word2id"):  # convectors WordVectors instance
+                self.word2id = {k: v for k, v in model.word2id.items()}
+            else:
+                self.word2id = {}
+                for word, index in model.wv.key_to_index.items():
+                    self.word2id[word] = index + 1  # offset index by 1
+            self.unk_token = "<UNK>" in self.word2id
+            self.mask_token = "<MASK>" in self.word2id
+            self.n_features = len(self.word2id)
+        elif word2id is not None:  # custom word2id mapping
             self.word2id = word2id
             self.unk_token = "<UNK>" in self.word2id
             self.mask_token = "<MASK>" in self.word2id
@@ -233,6 +245,7 @@ class OneHot(Layer):
             tf = Counter(itertools.chain(*series))
             self.multilabel = True
         else:
+            print(series)
             tf = Counter(series)
             self.multilabel = False
 
@@ -283,3 +296,48 @@ class OneHot(Layer):
         obj = deepcopy(self)
         obj.decode_mode = True
         return obj
+
+
+class Doc2Vec(Layer):
+    parallel = False
+    trainable = True
+    document_wise = False
+
+    def __init__(
+        self,
+        input=None,
+        output=None,
+        n_components=200,
+        min_tf=2,
+        epochs=40,
+        model=None,
+        name=None,
+        verbose=True
+    ):
+        super(Doc2Vec, self).__init__(input, output, name, verbose, False)
+        self.n_components = n_components
+        self.min_tf = min_tf
+        self.epochs = epochs
+        self.model = model
+
+    def fit(self, series, y=None):
+        import gensim
+
+        train_corpus = [gensim.models.doc2vec.TaggedDocument(
+            tokens, [i]) for i, tokens in enumerate(series)]
+
+        self.model = gensim.models.doc2vec.Doc2Vec(
+            vector_size=self.n_components,
+            min_count=self.min_tf,
+            epochs=self.epochs)
+        self.model.build_vocab(train_corpus)
+        self.model.train(
+            train_corpus,
+            total_examples=self.model.corpus_count,
+            epochs=self.model.epochs)
+
+    def process_series(self, series):
+        if self.model is None:
+            self.fit(series)
+        return np.array(
+            [self.model.infer_vector(doc) for doc in series])
